pub struct WayNodeLocation { /* private fields */ }Implementations
Sourceimpl WayNodeLocation
A node location that contains latitude and longitude coordinates.
impl WayNodeLocation
A node location that contains latitude and longitude coordinates.